@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
-
 __title__ = "waybackpy"
 __description__ = (
     "A Python package that interfaces with the Internet Archive's Wayback Machine API. "
     "Archive pages and retrieve archived pages easily."
 )
 __url__ = "https://akamhy.github.io/waybackpy/"
-__version__ = "2.3.1"
+__version__ = "2.4.0"
 __author__ = "akamhy"
-__author_email__ = "akash3pro@gmail.com"
+__author_email__ = "akamhy@yahoo.com"
 __license__ = "MIT"
-__copyright__ = "Copyright 2020 akamhy"
+__copyright__ = "Copyright 2020-2021 Akash Mahanty et al."
